*03-02-2023*
**_ Examining the Role of Intrinsic and Reflexive Contributions to Ankle Joint Hyper-Resistance Treated with Botulinum Toxin-A _**

# Introduction
For an optimal reading experience render this document with a Markdown parser.

This readme file describes the work presented in [1]. This repository with all code and data underlying [1] has been publicly published in the 4TU repository [2].

The work distinguishes the contribution of intrinsic and reflexive ankle joint resistance for participants treated with BoNT-A injections to reduce spasticity.

In short, we only observed the expected joint resistance reduction due to BoNT-A injections in the MAS (overall resistance). This observed reduction could not be attributed to an unambiguous group-level reduction of the reflexive resistance contribution, as no instrumented measure confirmed the hypothesis. Validity of the instrumented measures was supported through a strong association between different assessment methods.

This document provides an overview of the documents, data and other materials and directs to other documentation that provides and explains more details.

# Contents
1. How to use
2. Contact
3. References
4. Licensing
5. Files

# How to use
This repository covers all documents related to the execution, analysis and reporting of the work published in [1].

The *Code* folder contains all scripts/functions (MATLAB and R) and the *Data* folder contains all experimental data used within the project. The experiment was executed with the Achilles Perturbator device of the University of Twente, see the (private) Bitbucket repository/wiki for more information on the device [3]. The scripts within the *Code* folder are further supported by functions in *Code/Functions* and intermediate stored data *Code/Processed*. Additional details about the code and data can be found in a readme within each respective folder: **_!README_code.md_** and **_!README_data.md_**).

## Prerequisites
The experiment was performed on a Dell Precision 3541 laptop with an Intel Core i7-9750H processor, 32 GB RAM, running Windows 10. The data analysis and processing was performed on a Dell Precision 3510 laptop with an Intel Core i7-6700HQ processor, 16 GB RAM, running Window 10.

All MATLAB code was created, tested and run in MATLAB/Simulink 2017b. All R code was created, tested and run in R3.6.2. For both MATLAB and R, the code might be forward compatible or easily adaptable to newer versions otherwise.

# Contact
For questions and suggestions, please contact either:

Edwin van Asseldonk (e.h.f.vanasseldonk@utwente.nl)
or
Ronald van 't Veld (r.c.vantveld@utwente.nl)

Department of Biomechanical Engineering  
Faculty of Engineering Technology  
University of Twente  
Enschede, The Netherlands  

# References
[1] van 't Veld RC, Flux E, van Oorschot W, Schouten AC, van der Krogt MM, van der Kooij H, Vos-van der Hulst M, Keijsers NLW, van Asseldonk EHF. Examining the Role of Intrinsic and Reflexive Contributions to Ankle Joint Hyper-Resistance Treated with Botulinum Toxin-A. doi: [10.1186/s12984-023-01141-8](https://doi.org/10.1186/s12984-023-01141-8)
[2] van 't Veld RC, Flux E, van Oorschot W, Schouten AC, van der Krogt MM, van der Kooij H, Vos-van der Hulst M, Keijsers NLW, van Asseldonk EHF (2023): Code/Data underlying publication: Examining the Role of Intrinsic and Reflexive Contributions to Ankle Joint Hyper-Resistance Treated with Botulinum Toxin-A. 4TU.ResearchData. Collection. doi: [10.4121/c.5986267](https://doi.org/10.4121/c.5986267)
[3] [AchillesPerturbatorGUI: Bitbucket Repository](https://bitbucket.org/ctw-bw/achillesperturbatorgui)

# Licensing
"Examining the Role of Intrinsic and Reflexive Contributions to Ankle Joint Hyper-Resistance Treated with Botulinum Toxin-A" (c) by van 't Veld RC, Flux E, van Oorschot W, Schouten AC, van der Krogt MM, van der Kooij H, Vos-van der Hulst M, Keijsers NLW, van Asseldonk EHF
"Examining the Role of Intrinsic and Reflexive Contributions to Ankle Joint Hyper-Resistance Treated with Botulinum Toxin-A" is licensed under a Creative Commons Attribution 4.0 International License.  
You should have received a copy of the license along with this work. If not, see [CC BY 4.0](http://creativecommons.org/licenses/by/4.0/).

The software within the *Code* folder is licensed under a MIT License with the exception of the 'shadedErrorBar.m'-function.  
The 'shadedErrorBar.m'-function is licensed under a LGPL-3.0 license as this work was derived from the [Matlab File Exchange](https://nl.mathworks.com/matlabcentral/fileexchange/26311-raacampbell-shadederrorbar).

# Files
- [Code]
  The *Code* folder contains the MATLAB and R scripts used during the experiment and afterwards during analysis. Moreover, the code folder includes all functions and intermediate stored data in support of the analysis scripts.
	- [Functions]
	The *Functions* folder contains all MATLAB functions in support of the analysis scripts.
		- alignSortMechData.m
		- dZOHLpFilter.m
		- getMechStretchEnsembles.m
		- getStretchIndices.m
		- iccMDD.m
		- irfCorr.m
		- isolateRisingSlope.m
		- loadData.m
		- offlineSepStiffIdent.m
		- plotColors.m
		- plotMechEnsemble.m
		- shadedErrorBar.m
		- spatWork.m
		- subplotPositions.m
	- [Processed]
	The *Processed* folder contains data files with intermediate results, stored to enable re-use across languages (MATLAB and R) and scripts.
		- dataProcessed.mat
		- dataStats.mat
		- statsResult.mat
	- !LICENSE_code.md
	- !LICENSE_shadedErrorBar.md
	- !README.md
	- !README_code.md
	- analyzeCorrelations.R
	- analyzeSpasticity.m
	- analyzeTimeseries.m
	- trialAnalysis.m
- [Data]
The *Data* folder contains all experimental data from 9 participants, numbered Subject001 through Subject010.
	- [Subject001_Session01 - Subject010_Session03]
		- [A01_SetZero]
			- Trial2C1R1.mat
		- [A05_CaliAchilles]
			- Trial1C1R1.mat
		- [A08_TorqueMVC]
			- Trial4C1R1.mat
			- Trial4C1R2.mat
			- etc.
			- Trial4C2R3.mat
		- [D03_OfflineTIIdent]
			- Trial5C1R1.mat
			- Trial5C1R2.mat
		- [R03_QuadraticAsymROM]
			- Trial3C1R1.mat
			- Trial3C2R1.mat
		- Subject001_Session01.mat - Subject010_Session03.mat
	- !LICENSE_data.md
	- !README.md
	- !README_data.md
	- SMK_BoNTA.mat