# Introduction
The **_Code_** folder contains the MATLAB and R scripts used during the experiment and afterwards during analysis. Moreover, the code folder includes intermediate processed data, used directly in support of the code. This readme will focus on the post-experiment data analysis. The sections within this readme are in line with the subsections of the Results section in the article [1].

# Code Directory
- [Code]
	- [Functions]
	- [Processed]
		- dataProcessed.mat
		- dataStats.mat
		- statsResult.mat
	- !LICENSE_code.md
	- !LICENSE_shadedErrorBar.md
	- !README.md
	- !README_code.md
	- analyzeCorrelations.R
	- analyzeSpasticity.m
	- analyzeTimeseries.m
	- trialAnalysis.m
	
# Analysis Scripts	
## Pre-Analysis
The *trialAnalysis.m* was used before the actual results analysis. The *trialAnalysis.m* was used to create a feeling for the experimental data and potential data quality issues within the biomechanical data. For example, data was checked for completeness and missing samples.
	
## Experiment Time Series
The *analyzeTimeseries.m* script was used to analyze the timeseries data of the representative subjects (=Subject004 & Subject007). The timeseries analysis includes a study of the raw measured signals (e.g. position, torque) and ensemble averages over multiple over a single measurement block. The results are summarized in Figures 2 and 3 of the article.

## Longitudinal Evaluation
The *analyzeSpasticity.m* and *analyzeCorrelations.R* scripts were used to evaluate the longitudinal effects of the BoNT-A injections. The MATLAB script *analyzeSpasticity.m* was used for the full experimental data processing, including the within-subject statistics using the Friedman test and multiple comparisons. Furthermore, the MATLAB script was used to generate Figures 4 and 5 of the article. The R *analyzeCorrelations.R* script was used to compute the icc correlation coefficients and to perform the bootstrap analysis to obtain the 95% confidence intervals on the correlations. The *dataProcessed.mat*, *dataStats.mat* and *statsResult.mat* in the **_Processed_** folder are all used to store the results of the *analyzeCorrelations.m* and *analyzeCorrelations.R* scripts, such that the results are available within both scripting languages (both can process the MATLAB .mat file extension).

## Supporting Functions
The MATLAB functions supporting the analysis scripts elaborated on above are included in the **_Functions_** folder. The functions content will not be elaborated on in the readme and the reader is referred to the MATLAB-style function comments/explanations included general description and definitions of syntax, inputs and outputs. Plots were exported using the export_fig function from the [Matlab File Exchange](https://nl.mathworks.com/matlabcentral/fileexchange/23629-export_fig).

# References
[1] van 't Veld RC, Flux E, van Oorschot W, Schouten AC, van der Krogt MM, van der Kooij H, Vos-van der Hulst M, Keijsers NLW, van Asseldonk EHF. Examining the Role of Intrinsic and Reflexive Contributions to Ankle Joint Hyper-Resistance Treated with Botulinum Toxin-A. doi: [10.1186/s12984-023-01141-8](https://doi.org/10.1186/s12984-023-01141-8)