#Load all relevant libraries and empty workspace
library(R.matlab)
library(boot)
library(irr)
rm(list = ls())

#Pre-allocate the intrinsic and reflexive outputs
spearStore <- array(,dim=c(12,3))
pearsonStore <- array(,dim=c(9,3))
iccStore <- array(,dim=c(6,3))
# Read data from Matlab and set muscle index
data <- readMat('Processed/dataStats.mat')
# Set random seed for replication
set.seed(1)

# FUNCTIONS
corrBoot <- function(x,y,type){
  # Cross-store NaN from x/y vectors
  x[is.nan(y)] <- NaN
  y[is.nan(x)] <- NaN
  # Remove NaN
  x <- x[!is.nan(x)]
  y <- y[!is.nan(y)]
  
  # Compute correlation
  xyCor <- cor(cbind(x,y),method = type)
  # Compute CIs via bootstrap
  cor.boot <- function(data,k) cor(data[k,],method = type)[1,2]
  cor.xy <- boot(data=cbind(x,y),statistic=cor.boot,R=1999)
  ciCor <- boot.ci(cor.xy, conf = 0.95, type="bca")

  corrStore <- cbind(xyCor[1,2],t(ciCor$bca[4:5]))
}
iccBoot <- function(x){
  # Remove NaN from data vector
  x <- x[apply(!is.nan(x), 1, any),]
  
  # Compute correlation
  xICC <- icc(x,model="twoway",type="agreement",unit="single")
  # Compute CIs via bootstrap
  icc.boot <- function(data,k){
    iccModel <- icc(data[k,],model="twoway",type="agreement",unit="single")
    return(iccModel$value)
  }
  icc.xy <- boot(data=x,statistic=icc.boot,R=1999)
  ciICC <- boot.ci(icc.xy, conf = 0.95, type="bca")
  
  corrStore <- cbind(xICC$value,t(ciICC$bca[4:5]))
}

# Compute all Spearman correlations (i.e. ordinal clinical measures involved)
for (ii in 1:6){spearStore[ii,] <- corrBoot(data$corrData[,1],data$corrData[,ii+2],"spearman")}
for (ii in 1:6){spearStore[ii+6,] <- corrBoot(data$corrData[,2],data$corrData[,ii+2],"spearman")}

# Compute all Pearson's correlations (all continuous data)
for (jj in 1:3){
  for (ii in 1:3){pearsonStore[ii+3*(jj-1),] <- corrBoot(data$corrData[,jj+2],data$corrData[,ii+5],"pearson")}
}

# Compute all ICC and bootstraps (6x)
iccStore[1,] <- iccBoot(data$retestG)
iccStore[2,] <- iccBoot(data$retestK)
iccStore[3,] <- iccBoot(data$retestB)
iccStore[4,] <- iccBoot(data$retestSPATDiff)
iccStore[5,] <- iccBoot(data$retestSPATFast)
iccStore[6,] <- iccBoot(data$retestSPATSlow)

# Export the results to .mat file
writeMat('Processed/statsResult.mat',spearStore=spearStore,pearsonStore=pearsonStore,iccStore=iccStore)