%% Clean Start
clc, clearvars, close all;

%% Settings
% Overview of conditions to-be processed
Settings.isPlot = 2; % Flag to process plots: 0 = none, 1 = data-specific, 2 = all
% Define data storage location
dataCD = cd; fileSepIdxs = strfind(dataCD,filesep);
dataCD = dataCD(1:fileSepIdxs(end)-1);
dataSet = [dataCD '/Data/Subject001_Session01/D03_OfflineTIIdent/Trial5C1R1'];
% Data column/row order settings
Settings.mechDataColumns = [1 6 7 2 3 4 2]; % [-] Columns used to load data [time, posRef, velRef, posMeas, velMeas, tqMeas, Sync]

% Sys-ID (D03) Perturbation
Settings.pertAmpl = 0.035; % [rad] Amplitude (peak-to-peak)
% Filter settings
Settings.fcLpPos = 200;  % [Hz] Low-pass filter position for visualization
% Length of (bio)mechanical data segments
Settings.tSegStart = 0.04; % [s] Time before zero/onset
Settings.tSegEnd   = 0.4;  % [s] Time after zero/onset
% Create cell array of all perturbation characteristics to be sorted for
Settings.sortFields = {'rise','fall','pulse','step','stepFall','postPulse','postStep'};
% Normalization
Settings.isLocalTqNorm = 1; % Flag to normalize torque at start trial (if true) or with InitialTorque of session (if false)
Settings.isLocalPosNorm = 1; % Flag to normalize position at start trial (if true) or around the anatomical angles (if false)

% Add folder with all shared functions
addpath(genpath('Functions'));

%% Load data
% Load (bio)mechanical
[DataMech,Settings] = loadData(dataSet,Settings);

%% Post-trial online system identification
% Post-trial online seperation of intrinsic and reflexive stiffness
[~,~,~,~,SysIDSettings] = offlineSepStiffIdent(Settings.nReflIRF);
[DataSysID.kbi,DataSysID.gozd,DataSysID.VAF,DataSysID.SEM,~] = offlineSepStiffIdent(DataMech.posMeas,DataMech.velMeas,DataMech.tqMeas,SysIDSettings);

%% Time domain aligning & sorting
% Align and sort the (bio)mechanical data
MechEns = alignSortMechData(DataMech,Settings);

%% Figures
if (Settings.isPlot)
    % (Bio)mechanical time domain
    plotMechEnsemble(DataMech,MechEns,Settings);
end